#!/bin/sh

# check if release version has been provided
if [ $# -lt 1 ]; then
    echo "Usage: $0 RELEASE [PGP-KEY]"  
    echo "examples: "
    echo "    $0 1.0" 
    echo "    $0 1.1 \"Caspar Clemens Mierau\""
    exit 1
fi 

RELEASE="$1"
PGP_KEY="$2"
RELEASEDIR="bashup-${RELEASE}"

sign() {
    if [ "X$PGP_KEY" != "X" ]; then
        echo "  signing $1..."
        gpg --detach-sign --armor --sign "$1"
    fi
}

# make a clean bazaar export
if [ -e "../${RELEASEDIR}" ]; then
    echo "../${RELEASEDIR} exists, aborting."
    exit 1
fi
bzr export "../${RELEASEDIR}"
cd ..

echo "  writing version information..."
DATE=$(date)
for f in bashup_common.sh doc/bashup.1; do 
    sed -i "s/%REVISION%/${RELEASE}/g;s/%DATE%/${DATE}/g" "${RELEASEDIR}/$f"
done
echo ${RELEASE} > "${RELEASEDIR}/VERSION"

echo "  building gzip compressed tarball..."
tar czf "bashup-${RELEASE}.tar.gz" ${RELEASEDIR}
sign "bashup-${RELEASE}.tar.gz"
    
echo "  building bzip2 compressed tarball..."
tar cjf "bashup-${RELEASE}.tar.bz2" ${RELEASEDIR}
sign "bashup-${RELEASE}.tar.bz2"

echo "  building zip compressed archive..."
zip -q -r "bashup-${RELEASE}.zip" ${RELEASEDIR}
sign "bashup-${RELEASE}.zip"

echo "  building deb archive..."
(cd ${RELEASEDIR}
    dpkg-buildpackage -us -uc -rfakeroot)
sign "bashup_${RELEASE}_all.deb"

echo "done."